Overlay Filesystems
===================

.. only:: man

   Name
   ----

   mons-overlayfs \- Using an Overlay Filesystem for Everest


   Synopsis
   --------

   mons add NAME PATH --overlay OVERLAY_PATH


   Description
   -----------

.. include:: ../mons/overlayfs.py
   :start-after: {sphinx_description}
   :end-before: {sphinx_end}
